"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _helper = require("./helper");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class StoragePluginManager {
  constructor(config, packageName, logger, loadedBackends) {
    _defineProperty(this, "logger", void 0);

    _defineProperty(this, "packageName", void 0);

    _defineProperty(this, "config", void 0);

    _defineProperty(this, "packumentPackageStorage", void 0);

    _defineProperty(this, "tarballPackageStorage", void 0);

    this.logger = logger;
    this.packageName = packageName;
    this.config = config;
    const packumentBackend = (0, _helper.getBackend)(loadedBackends, this.config.packument_backend);
    this.packumentPackageStorage = packumentBackend.getPackageStorage(packageName);
    const tarballBackend = (0, _helper.getBackend)(loadedBackends, this.config.tarball_backend);
    this.tarballPackageStorage = tarballBackend.getPackageStorage(packageName);
  }

  updatePackage(name, updateHandler, onWrite, transformPackage, onEnd) {
    return this.packumentPackageStorage.updatePackage(name, updateHandler, onWrite, transformPackage, onEnd);
  }

  deletePackage(fileName, callback) {
    if (fileName.toLowerCase().endsWith('.tgz')) {
      return this.tarballPackageStorage.deletePackage(fileName, callback);
    }

    return this.packumentPackageStorage.deletePackage(fileName, callback);
  }

  removePackage(callback) {
    return this.packumentPackageStorage.removePackage(() => {
      this.tarballPackageStorage.removePackage(callback);
    });
  }

  createPackage(name, data, callback) {
    return this.packumentPackageStorage.createPackage(name, data, callback);
  }

  savePackage(pkgName, pkg, callback) {
    return this.packumentPackageStorage.savePackage(pkgName, pkg, callback);
  }

  readPackage(pkgName, callback) {
    return this.packumentPackageStorage.readPackage(pkgName, callback);
  }

  writeTarball(name) {
    return this.tarballPackageStorage.writeTarball(name);
  }

  readTarball(name) {
    return this.tarballPackageStorage.readTarball(name);
  }

}

exports.default = StoragePluginManager;