"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _pluginLoader = _interopRequireDefault(require("./plugin-loader"));

var _helper = require("./helper");

var _PackageStorage = _interopRequireDefault(require("./PackageStorage"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class VerdaccioStoragePlugin {
  // The object to hold loaded backend storages.
  constructor(config, options) {
    _defineProperty(this, "config", void 0);

    _defineProperty(this, "version", void 0);

    _defineProperty(this, "logger", void 0);

    _defineProperty(this, "loadedBackends", void 0);

    this.config = config;
    this.logger = options.logger; // load backends.

    this.loadedBackends = {};
    Object.keys(this.config.backends).forEach(pluginId => {
      const pluginConfig = this.config.backends[pluginId];
      const plugin_params = {
        config: this.config,
        logger: this.logger
      };
      const plugin = (0, _pluginLoader.default)(this.config, this.logger, pluginId, pluginConfig, plugin_params, plugin => {
        return plugin.getPackageStorage;
      });
      this.loadedBackends[pluginId] = plugin;
    });
  }

  async getSecret() {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.database_backend);
    return backend.getSecret();
  }

  async setSecret(secret) {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.database_backend);
    return backend.setSecret(secret);
  }

  add(name, callback) {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.database_backend);
    return backend.add(name, callback);
  }

  search(onPackage, onEnd, validateName) {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.search_backend);
    return backend.search(onPackage, onEnd, validateName);
  }

  remove(name, callback) {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.database_backend);
    return backend.remove(name, callback);
  }

  get(callback) {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.database_backend);
    return backend.get(callback);
  }
  /**
   * Create an instance of the `PackageStorage`
   * @param packageInfo
   */


  getPackageStorage(packageInfo) {
    return new _PackageStorage.default(this.config, packageInfo, this.logger, this.loadedBackends);
  }

  saveToken(token) {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.database_backend);
    return backend.saveToken(token);
  }

  deleteToken(user, tokenKey) {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.database_backend);
    return backend.deleteToken(user, tokenKey);
  }

  readTokens(filter) {
    const backend = (0, _helper.getBackend)(this.loadedBackends, this.config.database_backend);
    return backend.readTokens(filter);
  }

}

exports.default = VerdaccioStoragePlugin;